@@ -1,8 +1,20 @@
 import re
 
 from pygments.lexer import RegexLexer, include, bygroups, using, this
+from pygments.style import Style
 from pygments.token import Error, Punctuation, Text, Comment, Operator, Keyword, Name, String, Number
 
+class PseudocodeStyle(Style):
+    """Custom Style for Pseudocode fr"""
+    default_style = ""
+    styles = {
+        Comment:                'italic #888',
+        Keyword:                'bold #005',
+        Name:                   '#f00',
+        Name.Function:          '#0f0',
+        Name.Class:             'bold #0f0',
+        String:                 'bg:#eee #111'
+    }
 
 class PseudocodefrLexer(RegexLexer):
     '''
